@@ -30,15 +30,17 @@ import sys
 import typing
 
 import hikari
+from hikari.utilities import ux
 from multidict import CIMultiDict
 
 from lightbulb import commands
 from lightbulb import context as context_
 from lightbulb import errors
 from lightbulb import events
-from lightbulb import help as help_command
+from lightbulb import help as help_
 from lightbulb import plugins
 from lightbulb import stringview
+from lightbulb.utils import maybe_await
 
 _LOGGER = logging.getLogger("lightbulb")
 
@@ -136,7 +138,7 @@ class Bot(hikari.Bot):
         insensitive_commands: bool = False,
         ignore_bots: bool = True,
         owner_ids: typing.Iterable[int] = (),
-        help_class: typing.Type[help_command.HelpCommand] = help_command.HelpCommand,
+        help_class: typing.Type[help_.HelpCommand] = help_.HelpCommand,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -166,11 +168,21 @@ class Bot(hikari.Bot):
 
         self._help_impl = help_class(self)
 
+    @staticmethod
+    def print_banner(banner: typing.Optional[str], allow_color: bool, force_color: bool) -> None:
+        ux.print_banner(banner, allow_color, force_color)
+        if banner == "hikari":
+            sys.stdout.write(f"Thank you for using lightbulb!\n")
+
     @property
-    def help_class(self):
+    def help_command(self):
         """The instance of the help class used by the bot."""
         return self._help_impl
 
+    @help_command.setter
+    def help_command(self, new_help_instance: help_.HelpCommand):
+        self._help_impl = new_help_instance
+
     async def fetch_owner_ids(self) -> None:
         """
         Fetches the IDs of the bot's owner(s) from the API and stores them in
@@ -651,9 +663,12 @@ class Bot(hikari.Bot):
         return context_.Context(self, message, prefix, invoked_with, invoked_command)
 
     async def _evaluate_checks(self, command: commands.Command, context: context_.Context) -> bool:
-        failed_checks = []
+        checks = [*self._checks, *command.checks]
+        if command.plugin is not None:
+            checks.append(command.plugin.plugin_check)
 
-        for check in [*self._checks, *command._checks]:
+        failed_checks = []
+        for check in checks:
             try:
                 if not await check(context):
                     failed_checks.append(
@@ -697,9 +712,7 @@ class Bot(hikari.Bot):
             raise exception
 
     async def _resolve_prefix(self, message: hikari.Message) -> typing.Optional[str]:
-        prefixes = self.get_prefix(self, message)
-        if inspect.iscoroutine(prefixes):
-            prefixes = await prefixes
+        prefixes = await maybe_await(self.get_prefix, self, message)
 
         if isinstance(prefixes, str):
             prefixes = [prefixes]
@@ -716,9 +729,37 @@ class Bot(hikari.Bot):
             return command
         raise errors.CommandNotFound(invoked_with)
 
-    def _resolve_args_for_command(
+    def resolve_args_for_command(
         self, command: commands.Command, raw_arg_string: str
     ) -> typing.Tuple[typing.List[str], typing.Dict[str, str]]:
+        """
+        Resolve the appropriate command arguments from an unparsed string
+        containing the raw command arguments.
+
+        This method can be overridden if you wish to customise how arguments
+        are parsed for all the commands. If you override this then it is important that
+        it at least returns a tuple containing an empty list if no positional arguments
+        were resolved, and an empty dict if no keyword arguments were resolved.
+
+        If you override this method then you may find the :obj:`~.stringview.StringView`
+        class useful for extracting the arguments from the raw string and the property
+        :obj:`~.command.arg_details` which contains information about the command's arguments
+        and which are optional or required.
+
+        Args:
+            command (:obj:`~.commands.Command`): The command to resolve the arguments for.
+            raw_arg_string (:obj:`str`): String containing the raw, unparsed arguments.
+
+        Returns:
+            Tuple[ List[ :obj:`str` ], Dict[ :obj:`str1, :obj:`str` ] ]: Positional and keyword
+                arguments the command should be invoked with.
+
+        Raises:
+            :obj:`~.errors.TooManyArguments`: The command does not ignore extra arguments and too many
+                arguments were supplied by the user.
+            :obj:`~.errors.NotEnoughArguments`: Not enough arguments were provided by the user to fill
+                all required argument fields.
+        """
         sv = stringview.StringView(raw_arg_string)
         positional_args, remainder = sv.deconstruct_str(max_parse=command.arg_details.maximum_arguments)
         if remainder and command.arg_details.kwarg_name is None and not command._allow_extra_arguments:
@@ -796,9 +837,14 @@ class Bot(hikari.Bot):
             await before_invoke(context)
 
         try:
-            positional_args, keyword_arg = self._resolve_args_for_command(command, final_args)
+            positional_args, keyword_arg = self.resolve_args_for_command(command, final_args)
             await self._evaluate_checks(command, context)
-        except (errors.NotEnoughArguments, errors.TooManyArguments, errors.CheckFailure) as ex:
+        except (
+            errors.NotEnoughArguments,
+            errors.TooManyArguments,
+            errors.CheckFailure,
+            errors.CommandSyntaxError,
+        ) as ex:
             await self._dispatch_command_error_event_from_exception(ex, event.message, context, command)
             return
 
@@ -808,7 +854,7 @@ class Bot(hikari.Bot):
             await self._dispatch_command_error_event_from_exception(ex, event.message, context, command)
             return
         except Exception as ex:
-            new_ex = errors.CommandInvocationError("An error occurred during command invocation.", original=ex)
+            new_ex = errors.CommandInvocationError(f"{type(ex).__name__}: {ex}", original=ex)
             await self._dispatch_command_error_event_from_exception(new_ex, event.message, context, command)
             return
 
