@@ -35,11 +35,12 @@ import typing
 import hikari
 from multidict import CIMultiDict
 
-from lightbulb import context
+from lightbulb import context as context_
 from lightbulb import converters
 from lightbulb import cooldowns
 from lightbulb import errors
 from lightbulb import events
+from lightbulb.utils import maybe_await
 
 if typing.TYPE_CHECKING:
     from lightbulb import plugins
@@ -70,11 +71,20 @@ def _bind_prototype(instance: typing.Any, command_template: _CommandT):
         def __eq__(self, other) -> bool:
             return isinstance(other, (type(self), Command)) and other.name == self.name
 
-        async def invoke(self, context: context.Context, *args: str, **kwargs: str) -> typing.Any:
+        async def invoke(self, context: context_.Context, *args: str, **kwargs: str) -> typing.Any:
             if self.cooldown_manager is not None:
                 self.cooldown_manager.add_cooldown(context)
             # Add the start slice on to the length to offset the section of arg_details being extracted
             new_args = await self._convert_args(context, args, list(self.arg_details.args.values())[2 : len(args) + 2])
+
+            if kwargs:
+                new_kwarg = (
+                    await self._convert_args(
+                        context, kwargs.values(), [self.arg_details.args[self.arg_details.kwarg_name]]
+                    )
+                )[0]
+                kwargs = {self.arg_details.kwarg_name: new_kwarg}
+
             return await self._callback(instance, context, *new_args, **kwargs)
 
     prototype = BoundCommand()
@@ -209,12 +219,12 @@ class Command:
         """The plugin the command is registered to. If ``None`` then it was defined outside of a plugin."""
         self.user_required_permissions: hikari.Permissions = hikari.Permissions.NONE
         """
-        The permissions required by a user to run the command. 
+        The permissions required by a user to run the command.
         These are extracted from the permission check decorator(s) on the command.
         """
         self.bot_required_permissions: hikari.Permissions = hikari.Permissions.NONE
         """
-        The permissions the bot requires for a user to be able to run the command. 
+        The permissions the bot requires for a user to be able to run the command.
         These are extracted from the permission check decorator(s) on the command.
         """
 
@@ -405,8 +415,27 @@ class Command:
         return decorate
 
     @staticmethod
+    async def _handle_types(arg: str, details: ArgInfo):
+        if typing.get_origin(details.annotation) is typing.Union:
+            for typename in (types := typing.get_args(details.annotation)) :
+                try:
+                    if typename is not None:
+                        new_arg = await maybe_await(typename, arg)
+                    else:
+                        new_arg = typename(arg)
+                    return new_arg
+                except (ValueError, TypeError, errors.ConverterFailure):
+                    if typename == types[-1]:
+                        raise errors.ConverterFailure
+                    else:
+                        continue
+        else:
+            new_arg = await maybe_await(details.annotation, arg)
+            return new_arg
+
     async def _convert_args(
-        context: context.Context,
+        self,
+        context: context_.Context,
         args: typing.Sequence[str],
         arg_details: typing.Sequence[ArgInfo],
     ) -> typing.Sequence[typing.Any]:
@@ -418,18 +447,23 @@ class Command:
                 new_args.append(str(arg))
                 continue
             try:
-                new_arg = details.annotation(arg)
-                if inspect.iscoroutine(new_arg):
-                    new_arg = await new_arg
+                new_arg = await self._handle_types(arg, details)
                 new_args.append(new_arg)
-            except:
-                _LOGGER.error("Failed converting %s with converter: %s", arg, details.annotation.__name__)
-                raise errors.ConverterFailure(f"Failed converting {arg} with converter: {details.annotation.__name__}")
+            except (errors.ConverterFailure, ValueError):
+                _LOGGER.error(
+                    "Failed converting %s with converter: %s",
+                    arg,
+                    getattr(details.annotation, "__name__", repr(details.annotation)),
+                )
+                raise errors.ConverterFailure(
+                    f"Failed converting {arg} with converter: {getattr(details.annotation, '__name__', repr(details.annotation))}"
+                )
         return new_args
 
-    async def invoke(self, context: context.Context, *args: str, **kwargs: str) -> typing.Any:
+    async def invoke(self, context: context_.Context, *args: str, **kwargs: str) -> typing.Any:
         """
-        Invoke the command with given args and kwargs.
+        Invoke the command with given args and kwargs. Cooldowns and converters will
+        be processed however this method bypasses all command checks.
 
         Args:
             context (:obj:`~.context.Context`): The command invocation context.
@@ -482,7 +516,7 @@ class Command:
         """
         self._checks.append(check_func)
 
-    async def is_runnable(self, context: context.Context) -> bool:
+    async def is_runnable(self, context: context_.Context) -> bool:
         """
         Run all the checks for the command to determine whether or not it is
         runnable in the given context.
